PWSpacer class

PWSpacer: Simple spacing helpers using SizedBox.

Constructors

PWSpacer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

h(double height) SizedBox
Vertical space.
w(double width) SizedBox
Horizontal space.